@@ -8,7 +8,7 @@ from distutils.dir_util import copy_tree
 from funcy import retry
 
 from dvc.config import NoRemoteError
-from dvc.exceptions import RemoteNotSpecifiedInExternalRepoError
+from dvc.exceptions import NoRemoteInExternalRepoError
 from dvc.exceptions import NoOutputInExternalRepoError
 from dvc.exceptions import OutputNotFoundError
 from dvc.utils.fs import remove
@@ -25,8 +25,8 @@ def external_repo(url=None, rev=None, rev_lock=None, cache_dir=None):
     repo = Repo(path)
     try:
         yield repo
-    except NoRemoteError as exc:
-        raise RemoteNotSpecifiedInExternalRepoError(url, cause=exc)
+    except NoRemoteError:
+        raise NoRemoteInExternalRepoError(url)
     except OutputNotFoundError as exc:
         if exc.repo is repo:
             raise NoOutputInExternalRepoError(exc.output, repo.root_dir, url)
@@ -61,11 +61,14 @@ def _external_repo(url=None, rev=None, cache_dir=None):
         REPO_CACHE[url, None, None] = clean_clone_path
 
     # Adjust new clone/copy to fit rev and cache_dir
+
+    # Checkout needs to be done first because current branch might not be
+    # DVC repository
+    if rev is not None:
+        _git_checkout(new_path, rev)
+
     repo = Repo(new_path)
     try:
-        if rev is not None:
-            repo.scm.checkout(rev)
-
         if cache_dir is not None:
             cache_config = CacheConfig(repo.config)
             cache_config.set_dir(cache_dir, level=Config.LEVEL_LOCAL)
@@ -77,6 +80,16 @@ def _external_repo(url=None, rev=None, cache_dir=None):
     return new_path
 
 
+def _git_checkout(repo_path, revision):
+    from dvc.scm import Git
+
+    git = Git(repo_path)
+    try:
+        git.checkout(revision)
+    finally:
+        git.close()
+
+
 def clean_repos():
     # Outside code should not see cache while we are removing
     repo_paths = list(REPO_CACHE.values())
