@@ -48,7 +48,7 @@ class Updater(object):  # pragma: no cover
             logger.debug(msg.format(self.lock.lockfile, action))
 
     def check(self):
-        if os.getenv("CI") or env2bool("DVC_TEST"):
+        if os.getenv("CI") or env2bool("DVC_TEST") or PKG == "snap":
             return
 
         self._with_lock(self._check, "checking")
@@ -136,6 +136,7 @@ class Updater(object):  # pragma: no cover
                 "3. Download and install new binary"
             ),
             "conda": "Run {yellow}conda{reset} update dvc",
+            "choco": "Run {yellow}choco{reset} upgrade dvc",
             None: (
                 "Find the latest release at\n{blue}"
                 "https://github.com/iterative/dvc/releases/latest"
